==> ars_nouveau-1.19.2-3.13.3.464-sources.jar: com/hollingsworth/arsnouveau/client/waila/WailaArsNouveauPlugin.java <==
package com.hollingsworth.arsnouveau.client.waila;

import com.hollingsworth.arsnouveau.common.block.MobJar;
import com.hollingsworth.arsnouveau.common.block.tile.GhostWeaveTile;
import com.hollingsworth.arsnouveau.common.block.tile.MirrorWeaveTile;
import com.hollingsworth.arsnouveau.common.block.tile.SkyBlockTile;
import com.hollingsworth.arsnouveau.common.potions.ModPotions;
import net.minecraft.world.entity.player.Player;
import snownee.jade.api.BlockAccessor;
import snownee.jade.api.IWailaClientRegistration;
import snownee.jade.api.IWailaPlugin;
import snownee.jade.api.WailaPlugin;

@WailaPlugin
public class WailaArsNouveauPlugin implements IWailaPlugin {
    @Override
    public void registerClient(IWailaClientRegistration registration) {
        registration.registerBlockComponent(MobJarComponent.INSTANCE, MobJar.class);
        registration.addRayTraceCallback((hitResult, accessor, originalAccessor) -> {
            if (accessor instanceof BlockAccessor target) {
                Player player = accessor.getPlayer();

                if (player.isCreative() || player.isSpectator() || player.hasEffect(ModPotions.MAGIC_FIND_EFFECT.get()))
                    return accessor;

                if (target.getBlockEntity() instanceof GhostWeaveTile tile && tile.isInvisible()) {
                    return null;
                }
                if(target.getBlockEntity() instanceof SkyBlockTile skyWeave && !skyWeave.showFacade()){
                    return null;
                }

                if (target.getBlockEntity() instanceof MirrorWeaveTile tile) {
                    return registration.blockAccessor().from(target).blockState(tile.mimicState).build();
                }
            }
            return accessor;
        });
    }
}

==> ars_nouveau-1.21.1-5.8.3.1112-sources.jar: com/hollingsworth/arsnouveau/client/waila/WailaArsNouveauPlugin.java <==
package com.hollingsworth.arsnouveau.client.waila;

import com.hollingsworth.arsnouveau.common.block.MobJar;
import com.hollingsworth.arsnouveau.common.block.tile.GhostWeaveTile;
import com.hollingsworth.arsnouveau.common.block.tile.MirrorWeaveTile;
import com.hollingsworth.arsnouveau.common.block.tile.SkyBlockTile;
import com.hollingsworth.arsnouveau.setup.registry.ModPotions;
import net.minecraft.world.entity.player.Player;
import snownee.jade.api.*;

@WailaPlugin
public class WailaArsNouveauPlugin implements IWailaPlugin {
    @Override
    public void registerClient(IWailaClientRegistration registration) {
        registration.registerBlockComponent(MobJarComponent.INSTANCE, MobJar.class);
        registration.addRayTraceCallback((hitResult, accessor, originalAccessor) -> {
            if (accessor instanceof BlockAccessor target) {
                Player player = accessor.getPlayer();

                if (player.isCreative() || player.isSpectator() || player.hasEffect(ModPotions.MAGIC_FIND_EFFECT))
                    return accessor;

                if (target.getBlockEntity() instanceof GhostWeaveTile tile && tile.isInvisible()) {
                    return null;
                }
                if(target.getBlockEntity() instanceof SkyBlockTile skyWeave && !skyWeave.showFacade()){
                    return null;
                }

                if (target.getBlockEntity() instanceof MirrorWeaveTile tile) {
                    return registration.blockAccessor().from(target).blockState(tile.mimicState).build();
                }
            }
            return accessor;
        });
    }
}
